// Copyright (c) Mito
import React, { useState } from 'react';
import Dropdown from './Dropdown';
import DropdownItem from './DropdownItem';
import SelectDropdownIcon from '../icons/SelectDropdownIcon';
import { classNames } from '../../utils/classNames';
// import css
import '../../../css/elements/DropdownButton.css';
/**
 * The Dropdown Button component, which allows a user to select
 * an option from a list of items (while the displayed text on
 * the button stays static).
 *
 * If open, the select dropdown automatically closes when the user clicks.
 */
const DropdownButton = (props) => {
    const [displayDropdown, setDisplayDropdown] = useState(false);
    const width = props.width || 'block';
    const widthClass = `element-width-${width}`;
    const disabledClass = props.disabled ? 'dropdown-button-disabled' : 'dropdown-button-enabled';
    return (React.createElement("div", { className: classNames('dropdown-button', 'text-header-4', widthClass, disabledClass), onClick: () => {
            setDisplayDropdown((prevDisplayDropdown) => {
                /*
                    Only change the visibility of the dropdown if:
                    1) the button is not disabled AND
                    2) the button is not already open because the dropdown handles closing itself
                */
                if (!props.disabled && !prevDisplayDropdown) {
                    return true;
                }
                return prevDisplayDropdown;
            });
        } },
        React.createElement("p", { className: 'dropdown-button-text' }, props.children),
        React.createElement("div", { className: 'dropdown-button-icon-container' },
            React.createElement(SelectDropdownIcon, { purpleOrDarkOrWhite: props.disabled ? 'dark' : 'purple' })),
        displayDropdown &&
            React.createElement(Dropdown, { closeDropdown: () => setDisplayDropdown(false), searchable: props.searchable, width: props.dropdownWidth }, Object.keys(props.options).map((option, idx) => {
                return (React.createElement(DropdownItem, { key: idx, title: option, onClick: props.options[option] }));
            }))));
};
/*
    A helper function for turning an array and a callback for the elements in this
    array into a type that can be passed to `options` prop of the above dropdown button.

    See the PivotTable, where the column headers are used with a DropdownButton, for an
    example of usage of this function.
*/
export function getOptionsFromArray(elements, callback) {
    return elements.reduce((options, element) => {
        return Object.assign(Object.assign({}, options), { [element]: () => { callback(element); } });
    }, {});
}
export default DropdownButton;
//# sourceMappingURL=DropdownButton.js.map