import React from 'react';
import { FilterIcon } from '../icons/FilterIcons';
import '../../../css/endo/ColumnHeaders.css';
import { getBorderStyle, getIsCellSelected } from './selectionUtils';
import { cellInSearch, getCellDataFromCellIndexes, getTypeIcon } from './utils';
import { TaskpaneType } from '../taskpanes/taskpanes';
import { classNames } from '../../utils/classNames';
import Input from '../elements/Input';
import { focusGrid } from './focusUtils';
/*
    A single column header at the top of the sheet. If the edited
    cell is this header, then displays an input that allows the user
    to rename the header.
*/
const ColumnHeader = (props) => {
    var _a;
    const selected = getIsCellSelected(props.gridState.selections, -1, props.columnIndex);
    const width = props.gridState.widthDataArray[props.gridState.sheetIndex].widthArray[props.columnIndex];
    const { columnID, columnFilters, columnMitoType, columnHeader } = getCellDataFromCellIndexes(props.sheetData, -1, props.columnIndex);
    if (columnID === undefined || columnFilters === undefined || columnMitoType === undefined || columnHeader === undefined) {
        return React.createElement(React.Fragment, null);
    }
    const hasFilters = columnFilters.filters.length > 0;
    const editingColumnHeader = props.editorState !== undefined && props.editorState.rowIndex === -1 && props.editorState.columnIndex === props.columnIndex;
    const closeColumnHeaderEditor = () => {
        props.setEditorState(undefined);
        // We then focus on the grid, as we are no longer focused on the editor
        setTimeout(() => focusGrid(props.containerRef.current), 100);
    };
    return (React.createElement("div", { className: classNames('column-header-container', {
            'grabbable': props.columnHeaderOperation === 'reorder',
            'column-header-container-selected': selected,
            'column-header-container-searched': cellInSearch(columnHeader, props.gridState.searchString)
        }), onClick: () => {
            props.setUIState(prevUIState => {
                return Object.assign(Object.assign({}, prevUIState), { currOpenTaskpane: { type: TaskpaneType.CONTROL_PANEL } });
            });
        }, key: props.columnIndex, "mito-row-index": "-1", "mito-col-index": props.columnIndex, style: Object.assign({ width: `${width}px` }, getBorderStyle(props.gridState.selections, -1, props.columnIndex, props.sheetData.numRows)), onDragStart: (e) => {
            // Mark that this is a reordering that is happening
            e.dataTransfer.setData("operation", 'reorder');
            e.dataTransfer.setData("mito-col-index", props.columnIndex + '');
            props.setColumnHeaderOperation('reorder');
        }, onDragEnd: () => {
            props.setColumnHeaderOperation(undefined);
        }, 
        // We have to make it not draggable when we're editing the column header,
        // so that you can click within the input to move around. This is a FF bug
        // see here: https://newbedev.com/prevent-drag-event-to-interfere-with-input-elements-in-firefox-using-html5-drag-drop
        draggable: !editingColumnHeader ? 'true' : 'false' },
        !editingColumnHeader &&
            React.createElement(React.Fragment, null,
                React.createElement("div", { className: 'column-header-text', onClick: (e) => {
                        e.stopPropagation(); // stop prop, so we don't call the onclick the header container
                    }, onDoubleClick: (e) => {
                        e.stopPropagation(); // stop prop, so we don't call the onclick the header container
                        props.setEditorState({
                            rowIndex: -1,
                            columnIndex: props.columnIndex,
                            formula: columnHeader + '',
                        });
                    }, key: props.columnIndex, tabIndex: -1, 
                    // Display the entire column header if you hover over it 
                    title: columnHeader + '' }, columnHeader + ''),
                React.createElement("div", { className: 'column-header-right-side' },
                    React.createElement("div", { className: 'column-header-icons', title: 'Open the column control panel' },
                        React.createElement("span", { title: 'Edit filters' },
                            !hasFilters &&
                                React.createElement("div", { className: 'icon-color-changer-container' },
                                    React.createElement("div", { className: 'icon-hide-on-hover' },
                                        React.createElement(FilterIcon, { purpleOrDark: 'dark' })),
                                    React.createElement("div", { className: 'icon-show-on-hover' },
                                        React.createElement(FilterIcon, { purpleOrDark: 'purple' }))),
                            hasFilters &&
                                React.createElement(FilterIcon, { nonEmpty: true })),
                        React.createElement("div", { className: 'icon-color-changer-container' },
                            React.createElement("div", { className: 'icon-hide-on-hover' }, getTypeIcon(columnMitoType, 'dark')),
                            React.createElement("div", { className: 'icon-show-on-hover' }, getTypeIcon(columnMitoType, 'purple')))),
                    React.createElement("div", { className: 'column-header-resizer', onDragStart: (e) => {
                            e.stopPropagation();
                            // Mark that this is a resize
                            e.dataTransfer.setData("operation", 'resize');
                            e.dataTransfer.setData("mito-col-index", props.columnIndex + '');
                            props.setColumnHeaderOperation('resize');
                        }, onDragEnd: () => {
                            props.setColumnHeaderOperation(undefined);
                        }, draggable: "true" }))),
        editingColumnHeader &&
            React.createElement("form", { className: 'element-width-block', onSubmit: async (e) => {
                    var _a, _b;
                    e.preventDefault();
                    // Only submit the formula if it actually has changed
                    const newFormula = ((_a = props.editorState) === null || _a === void 0 ? void 0 : _a.formula) || (columnHeader + '');
                    if (newFormula !== (columnHeader + '')) {
                        void props.mitoAPI.sendRenameColumn(props.gridState.sheetIndex, columnID, ((_b = props.editorState) === null || _b === void 0 ? void 0 : _b.formula) || (columnHeader + ''));
                    }
                    closeColumnHeaderEditor();
                } },
                React.createElement(Input, { value: ((_a = props.editorState) === null || _a === void 0 ? void 0 : _a.formula) || '', onChange: (e) => {
                        const newHeader = e.target.value;
                        props.setEditorState((prevEditorState => {
                            if (prevEditorState === undefined)
                                return undefined;
                            return Object.assign(Object.assign({}, prevEditorState), { formula: newHeader });
                        }));
                    }, onKeyDown: (e) => {
                        if (e.key === 'Escape') {
                            closeColumnHeaderEditor();
                        }
                    }, autoFocus: true, width: 'block' }))));
};
export default React.memo(ColumnHeader);
//# sourceMappingURL=ColumnHeader.js.map