// Copyright (c) Mito
import React, { useEffect, useState } from 'react';
import { ModalEnum } from './modals';
import DefaultModal from '../DefaultModal';
import TextButton from '../elements/TextButton';
import RadioButtons from '../elements/RadioButtons';
export const shouldDisplayFeedbackModal = (numFeedbacks, numUsages) => {
    // NOTE: we start at 1 because users give their first feedback when they sign up!
    if (numUsages === 7 && numFeedbacks <= 1) {
        return true;
    }
    return false;
};
/*
  A modal that confirms with the user that they want to clear
  the entire analysis export for simple import steps
*/
const FeedbackModal = (props) => {
    const [firstResponse, setFirstResponse] = useState('');
    const [secondResponse, setSecondResponse] = useState('');
    const [submitted, setSubmitted] = useState(false);
    const FirstQuestion = 'What do you use the Mito generated code for?';
    const FirstQuestionAnswers = [
        'I don\'t use the generated code',
        'I copy the code and edit it',
        'I run the code to edit dataframes in my notebook',
    ];
    const SecondQuestion = 'Why are using Python for your analysis?';
    const SecondQuestionAnswers = [
        'I\'m automating a process',
        'My data is too large for Excel',
        'I\'m learning Python',
        'I\'m using functionality not in Excel (e.g. machine learning)'
    ];
    // Log when this opens
    useEffect(() => {
        void props.mitoAPI.sendLogMessage('opened_feedback_modal');
    }, []);
    return (React.createElement(DefaultModal, { header: `Some quick feedback on Mito`, modalType: ModalEnum.ClearAnalysis, viewComponent: React.createElement("div", { className: 'text-align-left' },
            React.createElement("label", null,
                React.createElement("h3", { className: 'text-body-1 mt-10px mb-5px' }, FirstQuestion)),
            React.createElement(RadioButtons, { values: FirstQuestionAnswers, selectedValue: firstResponse, onChange: (v) => setFirstResponse(v), highlight: submitted && firstResponse === '' }),
            React.createElement("label", null,
                React.createElement("h3", { className: 'text-body-1 mt-20px mb-5px' }, SecondQuestion)),
            React.createElement(RadioButtons, { values: SecondQuestionAnswers, selectedValue: secondResponse, onChange: (v) => setSecondResponse(v), highlight: submitted && secondResponse === '' })), buttons: React.createElement(React.Fragment, null,
            React.createElement(TextButton, { variant: 'dark', width: 'small', onClick: () => {
                    // Make sure it's filled out
                    if (firstResponse === '' || secondResponse === '') {
                        setSubmitted(true);
                        return;
                    }
                    // Otherwise, submit this as a feedback
                    void props.mitoAPI.sendFeedback({
                        [FirstQuestion]: firstResponse,
                        [SecondQuestion]: secondResponse
                    });
                    // And then close the modal
                    props.setUIState(prevUIState => {
                        return Object.assign(Object.assign({}, prevUIState), { currOpenModal: { type: ModalEnum.None } });
                    });
                } }, "Submit")) }));
};
export default FeedbackModal;
//# sourceMappingURL=FeedbackModal.js.map