// Copyright (c) Mito
import { DOMWidgetModel, DOMWidgetView, } from '@jupyter-widgets/base';
import { MODULE_NAME, MODULE_VERSION } from './version';
// React
import React from 'react';
import ReactDOM from 'react-dom';
// Components
import Mito from './components/Mito';
export class ExampleModel extends DOMWidgetModel {
    // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    defaults() {
        return Object.assign(Object.assign({}, super.defaults()), { _model_name: ExampleModel.model_name, _model_module: ExampleModel.model_module, _model_module_version: ExampleModel.model_module_version, _view_name: ExampleModel.view_name, _view_module: ExampleModel.view_module, _view_module_version: ExampleModel.view_module_version, df_json: '' });
    }
}
ExampleModel.serializers = Object.assign({}, DOMWidgetModel.serializers);
ExampleModel.model_name = 'ExampleModel';
ExampleModel.model_module = MODULE_NAME;
ExampleModel.model_module_version = MODULE_VERSION;
ExampleModel.view_name = 'ExampleView'; // Set to null if no view
ExampleModel.view_module = MODULE_NAME; // Set to null if no view
ExampleModel.view_module_version = MODULE_VERSION;
import MitoAPI from './api';
import { ModalEnum } from './components/modals/modals';
export class ExampleView extends DOMWidgetView {
    initialize(parameters) {
        super.initialize(parameters);
        // Bind the functions we pass down to other classes
        this.send = this.send.bind(this);
        this.updateSheetAndCode = this.updateSheetAndCode.bind(this);
        this.setErrorModal = this.setErrorModal.bind(this);
        this.creationSeconds = new Date().getSeconds();
    }
    /*
        We override the sending message utilities, just to make sure that
        this is captured properly
    */
    send(msg) {
        super.send(msg);
    }
    render() {
        var _a, _b;
        const model_id = this.model.model_id;
        const mitoAPI = new MitoAPI(model_id, this.send, this.updateSheetAndCode, this.setErrorModal);
        // Store the API in a global map so we can receive messages on it
        if (window.mitoAPIMap === undefined) {
            window.mitoAPIMap = new Map();
        }
        window.mitoAPIMap.set(model_id, mitoAPI);
        // Get the initial sheet data, analysis data, and user profile
        const sheetDataArray = this.getSheetDataArray();
        const analysisData = this.getAnalysisData();
        const userProfile = this.getUserProfile();
        ReactDOM.render(React.createElement(Mito, { model_id: model_id, mitoAPI: mitoAPI, sheetDataArray: sheetDataArray, analysisData: analysisData, userProfile: userProfile }), this.el);
        this.model.on('msg:custom', this.handleMessage, this);
        /*
            The first render of a widget happens when the mitosheet.sheet call is
            run. It does not occur when the page that this widget on is refreshed.
            
            We only need to send update events for df_names and reading an existing analysis
            in the case that this is the first render, and not when the page is refreshed.

            NOTE: Rerunning a mitosheet.sheet call that has an analysis in the cell
            below is _creating a new mitosheet_. Thus, this.getHasRendered() will
            return false in this case.
        */
        if (!userProfile.hasRendered) {
            // Get the arguments passed to the mitosheet.sheet call
            (_a = window.commands) === null || _a === void 0 ? void 0 : _a.execute('get-args').then(async (args) => {
                await mitoAPI.sendArgsUpdate(args);
            });
            // Get any previous analysis and send it back to the model!
            (_b = window.commands) === null || _b === void 0 ? void 0 : _b.execute('read-existing-analysis').then(async (analysisName) => {
                // If there is no previous analysis, we just ignore this step
                if (!analysisName)
                    return;
                // We log that we read from below, which is fine to come before the
                // using existing analysis since logging runs quickly
                await mitoAPI.sendLogMessage('read_analysis_from_cell_below', {
                    analysis_name: analysisName
                });
                // We send it to the backend
                await mitoAPI.sendUseExistingAnalysisUpdateMessage(analysisName, undefined, 
                /*
                    When we read in an analysis name from a cell, we replay this analysis
                    while also overwriting _everything_ that is already in the analysis.

                    This is to avoid issues w/ passing in a saved analysis to the mitosheet.sheet
                    call, where then rerunning the cell with this call w/ doubly-apply things.
                */
                true);
            });
        }
        // Let the backend know we have now rendered the sheet, and all future
        // renders therefor must be page refreshes, and so we let the backend 
        // know that we have rendered
        void mitoAPI.sendHasRenderedUpdated();
    }
    /*
        This is the function actually responsible for updating the Mito component
        with the new state, and is called by the MitoAPI when it receives a successful
        response from the backend!

        If you are adding a new shared variable, you want to add it's updating here
        if you want it to update on success.
    */
    updateSheetAndCode() {
        var _a, _b;
        const model_id = this.model.model_id;
        const stateUpdaters = (_a = window.setMitoStateMap) === null || _a === void 0 ? void 0 : _a.get(model_id);
        if (stateUpdaters === undefined) {
            return;
        }
        const sheetDataArray = this.getSheetDataArray();
        const analysisData = this.getAnalysisData();
        const userProfile = this.getUserProfile();
        // TODO: set analysis data, update user profile
        stateUpdaters.setSheetDataArray(sheetDataArray);
        stateUpdaters.setAnalysisData(analysisData);
        stateUpdaters.setUserProfile(userProfile);
        (_b = window.commands) === null || _b === void 0 ? void 0 : _b.execute('write-code-to-cell', {
            analysisName: analysisData.analysisName,
            code: analysisData.code,
            /*
                If there is an analysis that is read in and takes a bit to replay, then the code
                disappears for a little bit, which is pretty disorienting. As such, if we're writing
                empty code, and we're within the first 60 seconds of creating the sheet, then we do
                not actually clear the cell if there is something there. This stops an anlaysis that
                is read in from flashing
            */
            overwriteIfCodeEmpty: this.creationSeconds !== undefined ? (this.creationSeconds < (new Date().getSeconds() - 60)) : true
        });
    }
    /*
        Sets the current error modal on the Mito instance, which is useful
        (for now) when the frontend recieves a response that means an
        operation failed.

        This function should die once we start handling errors in place.
    */
    setErrorModal(error) {
        var _a;
        const model_id = this.model.model_id;
        const stateUpdaters = (_a = window.setMitoStateMap) === null || _a === void 0 ? void 0 : _a.get(model_id);
        stateUpdaters === null || stateUpdaters === void 0 ? void 0 : stateUpdaters.setUIState((prevUIState => {
            return Object.assign(Object.assign({}, prevUIState), { currOpenModal: {
                    type: ModalEnum.Error,
                    error: error
                } });
        }));
    }
    /*
        This route handles the messages sent from the Python widget, and mostly
        is just responsible for forwarding it to the correct Mito API.

        See the MitoAPI class comments for a full description of how the API process
        works and why it is designed the way it is.
    */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any, @typescript-eslint/explicit-module-boundary-types
    handleMessage(message) {
        var _a;
        const model_id = this.model.model_id;
        const mitoAPI = (_a = window.mitoAPIMap) === null || _a === void 0 ? void 0 : _a.get(model_id);
        mitoAPI === null || mitoAPI === void 0 ? void 0 : mitoAPI.receiveResponse(message);
    }
    getSheetDataArray() {
        const unparsed = this.model.get('sheet_data_json');
        return JSON.parse(unparsed);
    }
    getUserProfile() {
        const unparsed = this.model.get('user_profile_json');
        return JSON.parse(unparsed);
    }
    getAnalysisData() {
        const unparsed = this.model.get('analysis_data_json');
        return JSON.parse(unparsed);
    }
}
//# sourceMappingURL=widget.js.map